@@ -52,6 +52,7 @@ from .types.cluster_service import (
     DNSConfig,
     EphemeralStorageLocalSsdConfig,
     FastSocket,
+    Fleet,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
     GcfsConfig,
@@ -202,6 +203,7 @@ __all__ = (
     "DnsCacheConfig",
     "EphemeralStorageLocalSsdConfig",
     "FastSocket",
+    "Fleet",
     "GPUSharingConfig",
     "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
