@@ -48,6 +48,7 @@ from .cluster_service import (
     EphemeralStorageConfig,
     EphemeralStorageLocalSsdConfig,
     FastSocket,
+    Fleet,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
     GcfsConfig,
@@ -209,6 +210,7 @@ __all__ = (
     "EphemeralStorageConfig",
     "EphemeralStorageLocalSsdConfig",
     "FastSocket",
+    "Fleet",
     "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
     "GcfsConfig",
